@@ -3,7 +3,7 @@
 
 #include <glib-object.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk/gdktypes.h>
+#include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
@@ -58,6 +58,8 @@ NautilusIconInfo *    nautilus_icon_info_lookup                       (GIcon
 								       int                size);
 NautilusIconInfo *    nautilus_icon_info_lookup_from_name             (const char        *name,
 								       int                size);
+NautilusIconInfo *    nautilus_icon_info_lookup_from_path             (const char        *path,
+								       int                size);
 gboolean              nautilus_icon_info_is_fallback                  (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf                   (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf_nodefault         (NautilusIconInfo  *icon);
